/**
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 *
 *  Authors:
 *  2007-
 *     Oscar Koeroo <okoeroo@nikhef.nl>
 *     Mischa Sall\'e <msalle@nikhef.nl>
 *     David Groep <davidg@nikhef.nl>
 *     NIKHEF Amsterdam, the Netherlands
 *     <grid-mw-security@nikhef.nl>
 *
 */


#ifndef PDP_XACML_AUTHZ_PROCESS_H
 #define PDP_XACML_AUTHZ_PROCESS_H


#include <xacml.h>
#include <pthread.h>

#include "xacml_attr_obl_profile.h"


/* declarations */

extern pthread_mutex_t mutex;



/* prototype */

int
xacml_authorize(
    void *                              handler_arg,
    const xacml_request_t               request,
    xacml_response_t                    response);



int constructResponse (xacml_response_t * response,
                       uid_t uid,
                       gid_t pgid,
                       gid_t sgids[],
                       int   sgid_cnt);
int constructFailureResponse (xacml_response_t * response);
int extractRequestAction (const xacml_request_t           request,
                                xacml_profile_request_t * xacml_profile_request);
int extractRequestResource (const xacml_request_t           request,
                                  xacml_profile_request_t * xacml_profile_request);


void printRecvRequest (xacml_profile_request_t * xacml_profile_request);
int extractRequestSubject (const xacml_request_t           request,
                                 xacml_profile_request_t * xacml_profile_request);
int destroyRequestSubject (xacml_profile_request_t * xacml_profile_request);
int destroyRequestAction (xacml_profile_request_t * xacml_profile_request);
int destroyRequestResource (xacml_profile_request_t * xacml_profile_request);

/* Determines and sets the XACML response issuer, based on given portnumber */
int set_xacml_response_issuer(int portnumber);

/* Sets whether to use the cert_chain in the LCMAPS request, or DN and FQANs.
 * When set==-1, it does not change the value. The actual value is always
 * returned. */
int set_use_cert_chain(int set);


#endif /* PDP_XACML_AUTHZ_PROCESS_H */
